import React from 'react';
import PropTypes from 'prop-types';

import { noop } from '../../utils';
import './Button.styles.scss';

const STYlES = [
  "btn-pri-hi",
  "btn-sec-hi"
];

const SIZE = [
  "medium",
  "small"
];

/**
 * Text Button component that has floating label, caption, and info tooltip.
 *
 * `🧪Beta`
 *
 * @type {React.ForwardRefExoticComponent<{
 *   id?: string,
 *   color?: "primary" | "secondary" | "neutral",
 *   type?: "btn-pri-hi" | "btn-sec-hi",
 *   disabled?: boolean,
 *   children?: any,
 *   onClick?: function,
 *   extraClasses?: string
 * }>}
 */
const Button = React.forwardRef(
  (
    {
      id,
      color,
      type,
      disabled,
      onClick,
      children,
      extraClasses,
      ...props
   },
    ref
  ) => {

    const styleButton = STYlES.includes(type) ? type : STYlES[0];

    return (
      <button
        className={`btn ${styleButton}`}>
        BUTTOn
      </button>
    );
});


Button.propTypes = {
  /**
   * The id of button
   */
  id: PropTypes.string,
  color: PropTypes.oneOf(['primary', 'secondary', 'neutral']),
  type: PropTypes.oneOf(['btn-pri-hi', 'btn-sec-hi']),
  /**
   * Disabled button
   */
  disabled: PropTypes.bool,
  /**
   * Children
   */
  children: PropTypes.node,
  /**
   * Click event
   */
  onClick: PropTypes.func,
  /**
   * Additional classes to be added for customization
   */
  extraClasses: PropTypes.string,
};

Button.defaultProps = {
  id: '',
  color: 'primary',
  type: 'btn-pri-hi',
  disabled: false,
  children: null,
  onClick: noop,
  extraClasses: '',
};

export default Button;
