/**
 * Whole theme object
 */
export const theme: Readonly<{
    breakpoints: {
        sm: string;
        md: string;
        lg: string;
        xl: string;
        xxl: string;
        length: number;
        toString(): string;
        toLocaleString(): string;
        pop(): string;
        push(...items: string[]): number;
        concat(...items: ConcatArray<string>[]): string[];
        concat(...items: (string | ConcatArray<string>)[]): string[];
        join(separator?: string): string;
        reverse(): string[];
        shift(): string;
        slice(start?: number, end?: number): string[];
        sort(compareFn?: (a: string, b: string) => number): string[];
        splice(start: number, deleteCount?: number): string[];
        splice(start: number, deleteCount: number, ...items: string[]): string[];
        unshift(...items: string[]): number;
        indexOf(searchElement: string, fromIndex?: number): number;
        lastIndexOf(searchElement: string, fromIndex?: number): number;
        every<S extends string>(predicate: (value: string, index: number, array: string[]) => value is S, thisArg?: any): this is S[];
        every(predicate: (value: string, index: number, array: string[]) => unknown, thisArg?: any): boolean;
        some(predicate: (value: string, index: number, array: string[]) => unknown, thisArg?: any): boolean;
        forEach(callbackfn: (value: string, index: number, array: string[]) => void, thisArg?: any): void;
        map<U>(callbackfn: (value: string, index: number, array: string[]) => U, thisArg?: any): U[];
        filter<S_1 extends string>(predicate: (value: string, index: number, array: string[]) => value is S_1, thisArg?: any): S_1[];
        filter(predicate: (value: string, index: number, array: string[]) => unknown, thisArg?: any): string[];
        reduce(callbackfn: (previousValue: string, currentValue: string, currentIndex: number, array: string[]) => string): string;
        reduce(callbackfn: (previousValue: string, currentValue: string, currentIndex: number, array: string[]) => string, initialValue: string): string;
        reduce<U_1>(callbackfn: (previousValue: U_1, currentValue: string, currentIndex: number, array: string[]) => U_1, initialValue: U_1): U_1;
        reduceRight(callbackfn: (previousValue: string, currentValue: string, currentIndex: number, array: string[]) => string): string;
        reduceRight(callbackfn: (previousValue: string, currentValue: string, currentIndex: number, array: string[]) => string, initialValue: string): string;
        reduceRight<U_2>(callbackfn: (previousValue: U_2, currentValue: string, currentIndex: number, array: string[]) => U_2, initialValue: U_2): U_2;
        find<S_2 extends string>(predicate: (this: void, value: string, index: number, obj: string[]) => value is S_2, thisArg?: any): S_2;
        find(predicate: (value: string, index: number, obj: string[]) => unknown, thisArg?: any): string;
        findIndex(predicate: (value: string, index: number, obj: string[]) => unknown, thisArg?: any): number;
        fill(value: string, start?: number, end?: number): string[];
        copyWithin(target: number, start: number, end?: number): string[];
        entries(): IterableIterator<[number, string]>;
        keys(): IterableIterator<number>;
        values(): IterableIterator<string>;
        includes(searchElement: string, fromIndex?: number): boolean;
        flatMap<U_3, This = undefined>(callback: (this: This, value: string, index: number, array: string[]) => U_3 | readonly U_3[], thisArg?: This): U_3[];
        flat<A, D extends number = 1>(this: A, depth?: D): FlatArray<A, D>[];
        [Symbol.iterator](): IterableIterator<string>;
        [Symbol.unscopables](): {
            copyWithin: boolean;
            entries: boolean;
            fill: boolean;
            find: boolean;
            findIndex: boolean;
            keys: boolean;
            values: boolean;
        };
    };
    mediaQueries: {
        tablet: string;
        desktop: string;
    };
    sizes: {
        [x: number]: string;
        vW: string;
        vH: string;
        quarter: string;
        third: string;
        half: string;
        twoThird: string;
        threeQuarter: string;
        full: string;
        icons: string[];
        1: string;
    };
    fonts: {
        body: string;
        heading: string;
        monospace: string;
    };
    fontWeights: {
        regular: number;
        bold: number;
        body: number;
        heading: number;
        normal: number;
    };
    colors: {
        line: string;
        buttonRed: string;
        buttonBlue: string;
        green50: string;
        green100: string;
        green200: string;
        green300: string;
        green400: string;
        green500: string;
        green600: string;
        green700: string;
        green800: string;
        green900: string;
        yellow50: string;
        yellow100: string;
        yellow200: string;
        yellow300: string;
        yellow400: string;
        yellow500: string;
        yellow600: string;
        yellow700: string;
        yellow800: string;
        yellow900: string;
        white: string;
        black: string;
        backgroundIOS: string;
        grayIOS: string;
        /**
         * Main body text color
         * @type {string}
         */
        text: string;
        /**
         * De-emphasized / footer text color
         * @type {string}
         */
        textLighter: string;
        /**
         * Regular hyperlinks color
         * @type {string}
         */
        link: string;
        /**
         * Primary brand color for links, buttons, etc.
         * @type {string}
         */
        primary: string;
        /**
         * A secondary brand color for alternative styling
         * @type {string}
         */
        secondary: string;
        green: string;
        yellow: string;
        /**
         * Color for borders
         */
        border: string;
        background: string;
        text038: string;
        text060: string;
        text087: string;
        text025: string;
        text600: string;
        text900: string;
        warning50: string;
        warning800: string;
        success50: string;
        success700: string;
        error50: string;
        error900: string;
        surface1: string;
        surface2: string;
        surface3: string;
        surface25: string;
        surface100: string;
        surface300: string;
        surface500: string;
        surface700: string;
        surface900: string;
        gray50: string;
        gray100: string;
        gray200: string;
        gray300: string;
        gray400: string;
        gray500: string;
        gray600: string;
        gray700: string;
        gray800: string;
        gray900: string;
        darkgray1: string;
        darkgray2: string;
        darkgray3: string;
        darkgray4: string;
        gray1: string;
        gray2: string;
        gray3: string;
        gray4: string;
        gray5: string;
        secondary50: string;
        secondary100: string;
        secondary200: string;
        secondary300: string;
        secondary400: string;
        secondary500: string;
        secondary600: string;
        secondary700: string;
        secondary800: string;
        secondary900: string;
        primary50: string;
        primary100: string;
        primary200: string;
        primary300: string;
        primary400: string;
        primary500: string;
        primary600: string;
        primary700: string;
        primary800: string;
        primary900: string;
    };
    radii: {
        /**
         * No border radius
         */
        none: number;
        /**
         * Used for images, thumbnails
         */
        xs: string;
        /**
         * Used for buttons
         */
        sm: string;
        /**
         * Unused
         */
        md: string;
        /**
         * Unused
         */
        lg: string;
        /**
         * Used for c2c home page thumbnails
         */
        xl: string;
        /**
         * Used for pill buttons
         *
         * '9999px'
         */
        pill: string;
        /**
         * Used for icons frames
         *
         * '100%'
         */
        circle: string;
    };
    inputHeights: {
        sm: string;
        md: string;
        xs: string;
    };
    texts: {
        text038: string;
        text060: string;
        text087: string;
        text025: string;
        text600: string;
        text900: string;
    };
    zIndices: {
        initial: string;
        neutral: number;
        up: number;
        down: number;
        notification: number;
        tooltip: number;
        modal: number;
        dropdown: number;
    };
}>;
export default theme;
