/**
 * @typedef {import('styled-system__css').CSSProperties} CSSProperties
 * @typedef {import('styled-system__css').SystemStyleObject} SystemStyleObject
 */
/**
 * @typedef { keyof theme['colors'] } Colors
 * @typedef { keyof theme['fonts'] } Fonts
 * @typedef { keyof theme['fontWeights'] } FontWeights
 * @typedef { keyof theme['radii'] } Radii
 * @typedef { keyof theme['sizes'] } Sizes
 */
/**
 * @typedef {object} ThemableStyle - Themeable style object
 * @property {Fonts | Fonts[]}                 [fontFamily]
 * @property {FontWeights | FontWeights[]}     [fontWeight]
 * @property {string | string[]}               [lineHeight]
 * @property {string | string[]}               [letterSpacing]
 * @property {Colors | Colors[]}               [color]
 * @property {Colors | Colors[]}               [backgroundColor]
 * @property {Colors | Colors[]}               [bg] short hand for background color
 * @property {string | string[]}               [border]
 * @property {string | string[]}               [borderTop]
 * @property {string | string[]}               [borderRight]
 * @property {string | string[]}               [borderBottom]
 * @property {string | string[]}               [borderLeft]
 * @property {Colors | Colors[]}               [borderColor]
 * @property {string|string[]}                 [borderStyle]
 * @property {Radii | Radii[] }                [borderRadius]
 * @property {number | number[]}               [zIndex]
 * @property {Sizes | Sizes[]}                 [width]
 * @property {Sizes | Sizes[]}                 [minWidth]
 * @property {Sizes | Sizes[]}                 [maxWidth]
 * @property {Sizes | Sizes[]}                 [height]
 * @property {Sizes | Sizes[]}                 [minHeight]
 * @property {Sizes | Sizes[]}                 [maxHeight]
 * @property {Sizes | Sizes[]}                 [size]
 */
/**
 * @typedef {Omit<CSSProperties, keyof ThemableStyle>} StandardCSSProperties All standard CSS properties as regular object, except those from ThemableStyle
 */
/**
 * Helper get CSS from theme-aware style object and theme
 * @param {ThemableStyle | StandardCSSProperties} styles
 * @return {import('styled-system__css').CSSObject}
 */
export default function sx(styles?: ThemableStyle | StandardCSSProperties): import('styled-system__css').CSSObject;
export type CSSProperties = import('styled-system__css').CSSProperties;
export type SystemStyleObject = import('styled-system__css').SystemStyleObject;
export type Colors = keyof {
    readonly breakpoints: {
        sm: string;
        md: string;
        lg: string;
        xl: string;
        xxl: string;
        length: number;
        toString(): string;
        toLocaleString(): string;
        pop(): string;
        push(...items: string[]): number;
        concat(...items: ConcatArray<string>[]): string[];
        concat(...items: (string | ConcatArray<string>)[]): string[];
        join(separator?: string): string;
        reverse(): string[];
        shift(): string;
        slice(start?: number, end?: number): string[];
        sort(compareFn?: (a: string, b: string) => number): string[];
        splice(start: number, deleteCount?: number): string[];
        splice(start: number, deleteCount: number, ...items: string[]): string[];
        unshift(...items: string[]): number;
        indexOf(searchElement: string, fromIndex?: number): number;
        lastIndexOf(searchElement: string, fromIndex?: number): number;
        every<S extends string>(predicate: (value: string, index: number, array: string[]) => value is S, thisArg?: any): this is S[];
        every(predicate: (value: string, index: number, array: string[]) => unknown, thisArg?: any): boolean;
        some(predicate: (value: string, index: number, array: string[]) => unknown, thisArg?: any): boolean;
        forEach(callbackfn: (value: string, index: number, array: string[]) => void, thisArg?: any): void;
        map<U>(callbackfn: (value: string, index: number, array: string[]) => U, thisArg?: any): U[];
        filter<S_1 extends string>(predicate: (value: string, index: number, array: string[]) => value is S_1, thisArg?: any): S_1[];
        filter(predicate: (value: string, index: number, array: string[]) => unknown, thisArg?: any): string[];
        reduce(callbackfn: (previousValue: string, currentValue: string, currentIndex: number, array: string[]) => string): string;
        reduce(callbackfn: (previousValue: string, currentValue: string, currentIndex: number, array: string[]) => string, initialValue: string): string;
        reduce<U_1>(callbackfn: (previousValue: U_1, currentValue: string, currentIndex: number, array: string[]) => U_1, initialValue: U_1): U_1;
        reduceRight(callbackfn: (previousValue: string, currentValue: string, currentIndex: number, array: string[]) => string): string;
        reduceRight(callbackfn: (previousValue: string, currentValue: string, currentIndex: number, array: string[]) => string, initialValue: string): string;
        reduceRight<U_2>(callbackfn: (previousValue: U_2, currentValue: string, currentIndex: number, array: string[]) => U_2, initialValue: U_2): U_2;
        find<S_2 extends string>(predicate: (this: void, value: string, index: number, obj: string[]) => value is S_2, thisArg?: any): S_2;
        find(predicate: (value: string, index: number, obj: string[]) => unknown, thisArg?: any): string;
        findIndex(predicate: (value: string, index: number, obj: string[]) => unknown, thisArg?: any): number;
        fill(value: string, start?: number, end?: number): string[];
        copyWithin(target: number, start: number, end?: number): string[];
        entries(): IterableIterator<[number, string]>;
        keys(): IterableIterator<number>;
        values(): IterableIterator<string>;
        includes(searchElement: string, fromIndex?: number): boolean;
        flatMap<U_3, This = undefined>(callback: (this: This, value: string, index: number, array: string[]) => U_3 | readonly U_3[], thisArg?: This): U_3[];
        flat<A, D extends number = 1>(this: A, depth?: D): FlatArray<A, D>[];
        [Symbol.iterator](): IterableIterator<string>;
        [Symbol.unscopables](): {
            copyWithin: boolean;
            entries: boolean;
            fill: boolean;
            find: boolean;
            findIndex: boolean;
            keys: boolean;
            values: boolean;
        };
    };
    readonly mediaQueries: {
        tablet: string;
        desktop: string;
    };
    readonly sizes: {
        [x: number]: string;
        vW: string;
        vH: string;
        quarter: string;
        third: string;
        half: string;
        twoThird: string;
        threeQuarter: string;
        full: string;
        icons: string[];
        1: string;
    };
    readonly fonts: {
        body: string;
        heading: string;
        monospace: string;
    };
    readonly fontWeights: {
        regular: number;
        bold: number;
        body: number;
        heading: number;
        normal: number;
    };
    readonly colors: {
        line: string;
        buttonRed: string;
        buttonBlue: string;
        green50: string;
        green100: string;
        green200: string;
        green300: string;
        green400: string;
        green500: string;
        green600: string;
        green700: string;
        green800: string;
        green900: string;
        yellow50: string;
        yellow100: string;
        yellow200: string;
        yellow300: string;
        yellow400: string;
        yellow500: string;
        yellow600: string;
        yellow700: string;
        yellow800: string;
        yellow900: string;
        white: string;
        black: string;
        backgroundIOS: string;
        grayIOS: string;
        text: string;
        textLighter: string;
        link: string;
        primary: string;
        secondary: string;
        green: string;
        yellow: string;
        border: string;
        background: string;
        text038: string;
        text060: string;
        text087: string;
        text025: string;
        text600: string;
        text900: string;
        warning50: string;
        warning800: string;
        success50: string;
        success700: string;
        error50: string;
        error900: string;
        surface1: string;
        surface2: string;
        surface3: string;
        surface25: string;
        surface100: string;
        surface300: string;
        surface500: string;
        surface700: string;
        surface900: string;
        gray50: string;
        gray100: string;
        gray200: string;
        gray300: string;
        gray400: string;
        gray500: string;
        gray600: string;
        gray700: string;
        gray800: string;
        gray900: string;
        darkgray1: string;
        darkgray2: string;
        darkgray3: string;
        darkgray4: string;
        gray1: string;
        gray2: string;
        gray3: string;
        gray4: string;
        gray5: string;
        secondary50: string;
        secondary100: string;
        secondary200: string;
        secondary300: string;
        secondary400: string;
        secondary500: string;
        secondary600: string;
        secondary700: string;
        secondary800: string;
        secondary900: string;
        primary50: string;
        primary100: string;
        primary200: string;
        primary300: string;
        primary400: string;
        primary500: string;
        primary600: string;
        primary700: string;
        primary800: string;
        primary900: string;
    };
    readonly radii: {
        none: number;
        xs: string;
        sm: string;
        md: string;
        lg: string;
        xl: string;
        pill: string;
        circle: string;
    };
    readonly inputHeights: {
        sm: string;
        md: string;
        xs: string;
    };
    readonly texts: {
        text038: string;
        text060: string;
        text087: string;
        text025: string;
        text600: string;
        text900: string;
    };
    readonly zIndices: {
        initial: string;
        neutral: number;
        up: number;
        down: number;
        notification: number;
        tooltip: number;
        modal: number;
        dropdown: number;
    };
}['colors'];
export type Fonts = keyof {
    readonly breakpoints: {
        sm: string;
        md: string;
        lg: string;
        xl: string;
        xxl: string;
        length: number;
        toString(): string;
        toLocaleString(): string;
        pop(): string;
        push(...items: string[]): number;
        concat(...items: ConcatArray<string>[]): string[];
        concat(...items: (string | ConcatArray<string>)[]): string[];
        join(separator?: string): string;
        reverse(): string[];
        shift(): string;
        slice(start?: number, end?: number): string[];
        sort(compareFn?: (a: string, b: string) => number): string[];
        splice(start: number, deleteCount?: number): string[];
        splice(start: number, deleteCount: number, ...items: string[]): string[];
        unshift(...items: string[]): number;
        indexOf(searchElement: string, fromIndex?: number): number;
        lastIndexOf(searchElement: string, fromIndex?: number): number;
        every<S extends string>(predicate: (value: string, index: number, array: string[]) => value is S, thisArg?: any): this is S[];
        every(predicate: (value: string, index: number, array: string[]) => unknown, thisArg?: any): boolean;
        some(predicate: (value: string, index: number, array: string[]) => unknown, thisArg?: any): boolean;
        forEach(callbackfn: (value: string, index: number, array: string[]) => void, thisArg?: any): void;
        map<U>(callbackfn: (value: string, index: number, array: string[]) => U, thisArg?: any): U[];
        filter<S_1 extends string>(predicate: (value: string, index: number, array: string[]) => value is S_1, thisArg?: any): S_1[];
        filter(predicate: (value: string, index: number, array: string[]) => unknown, thisArg?: any): string[];
        reduce(callbackfn: (previousValue: string, currentValue: string, currentIndex: number, array: string[]) => string): string;
        reduce(callbackfn: (previousValue: string, currentValue: string, currentIndex: number, array: string[]) => string, initialValue: string): string;
        reduce<U_1>(callbackfn: (previousValue: U_1, currentValue: string, currentIndex: number, array: string[]) => U_1, initialValue: U_1): U_1;
        reduceRight(callbackfn: (previousValue: string, currentValue: string, currentIndex: number, array: string[]) => string): string;
        reduceRight(callbackfn: (previousValue: string, currentValue: string, currentIndex: number, array: string[]) => string, initialValue: string): string;
        reduceRight<U_2>(callbackfn: (previousValue: U_2, currentValue: string, currentIndex: number, array: string[]) => U_2, initialValue: U_2): U_2;
        find<S_2 extends string>(predicate: (this: void, value: string, index: number, obj: string[]) => value is S_2, thisArg?: any): S_2;
        find(predicate: (value: string, index: number, obj: string[]) => unknown, thisArg?: any): string;
        findIndex(predicate: (value: string, index: number, obj: string[]) => unknown, thisArg?: any): number;
        fill(value: string, start?: number, end?: number): string[];
        copyWithin(target: number, start: number, end?: number): string[];
        entries(): IterableIterator<[number, string]>;
        keys(): IterableIterator<number>;
        values(): IterableIterator<string>;
        includes(searchElement: string, fromIndex?: number): boolean;
        flatMap<U_3, This = undefined>(callback: (this: This, value: string, index: number, array: string[]) => U_3 | readonly U_3[], thisArg?: This): U_3[];
        flat<A, D extends number = 1>(this: A, depth?: D): FlatArray<A, D>[];
        [Symbol.iterator](): IterableIterator<string>;
        [Symbol.unscopables](): {
            copyWithin: boolean;
            entries: boolean;
            fill: boolean;
            find: boolean;
            findIndex: boolean;
            keys: boolean;
            values: boolean;
        };
    };
    readonly mediaQueries: {
        tablet: string;
        desktop: string;
    };
    readonly sizes: {
        [x: number]: string;
        vW: string;
        vH: string;
        quarter: string;
        third: string;
        half: string;
        twoThird: string;
        threeQuarter: string;
        full: string;
        icons: string[];
        1: string;
    };
    readonly fonts: {
        body: string;
        heading: string;
        monospace: string;
    };
    readonly fontWeights: {
        regular: number;
        bold: number;
        body: number;
        heading: number;
        normal: number;
    };
    readonly colors: {
        line: string;
        buttonRed: string;
        buttonBlue: string;
        green50: string;
        green100: string;
        green200: string;
        green300: string;
        green400: string;
        green500: string;
        green600: string;
        green700: string;
        green800: string;
        green900: string;
        yellow50: string;
        yellow100: string;
        yellow200: string;
        yellow300: string;
        yellow400: string;
        yellow500: string;
        yellow600: string;
        yellow700: string;
        yellow800: string;
        yellow900: string;
        white: string;
        black: string;
        backgroundIOS: string;
        grayIOS: string;
        text: string;
        textLighter: string;
        link: string;
        primary: string;
        secondary: string;
        green: string;
        yellow: string;
        border: string;
        background: string;
        text038: string;
        text060: string;
        text087: string;
        text025: string;
        text600: string;
        text900: string;
        warning50: string;
        warning800: string;
        success50: string;
        success700: string;
        error50: string;
        error900: string;
        surface1: string;
        surface2: string;
        surface3: string;
        surface25: string;
        surface100: string;
        surface300: string;
        surface500: string;
        surface700: string;
        surface900: string;
        gray50: string;
        gray100: string;
        gray200: string;
        gray300: string;
        gray400: string;
        gray500: string;
        gray600: string;
        gray700: string;
        gray800: string;
        gray900: string;
        darkgray1: string;
        darkgray2: string;
        darkgray3: string;
        darkgray4: string;
        gray1: string;
        gray2: string;
        gray3: string;
        gray4: string;
        gray5: string;
        secondary50: string;
        secondary100: string;
        secondary200: string;
        secondary300: string;
        secondary400: string;
        secondary500: string;
        secondary600: string;
        secondary700: string;
        secondary800: string;
        secondary900: string;
        primary50: string;
        primary100: string;
        primary200: string;
        primary300: string;
        primary400: string;
        primary500: string;
        primary600: string;
        primary700: string;
        primary800: string;
        primary900: string;
    };
    readonly radii: {
        none: number;
        xs: string;
        sm: string;
        md: string;
        lg: string;
        xl: string;
        pill: string;
        circle: string;
    };
    readonly inputHeights: {
        sm: string;
        md: string;
        xs: string;
    };
    readonly texts: {
        text038: string;
        text060: string;
        text087: string;
        text025: string;
        text600: string;
        text900: string;
    };
    readonly zIndices: {
        initial: string;
        neutral: number;
        up: number;
        down: number;
        notification: number;
        tooltip: number;
        modal: number;
        dropdown: number;
    };
}['fonts'];
export type FontWeights = keyof {
    readonly breakpoints: {
        sm: string;
        md: string;
        lg: string;
        xl: string;
        xxl: string;
        length: number;
        toString(): string;
        toLocaleString(): string;
        pop(): string;
        push(...items: string[]): number;
        concat(...items: ConcatArray<string>[]): string[];
        concat(...items: (string | ConcatArray<string>)[]): string[];
        join(separator?: string): string;
        reverse(): string[];
        shift(): string;
        slice(start?: number, end?: number): string[];
        sort(compareFn?: (a: string, b: string) => number): string[];
        splice(start: number, deleteCount?: number): string[];
        splice(start: number, deleteCount: number, ...items: string[]): string[];
        unshift(...items: string[]): number;
        indexOf(searchElement: string, fromIndex?: number): number;
        lastIndexOf(searchElement: string, fromIndex?: number): number;
        every<S extends string>(predicate: (value: string, index: number, array: string[]) => value is S, thisArg?: any): this is S[];
        every(predicate: (value: string, index: number, array: string[]) => unknown, thisArg?: any): boolean;
        some(predicate: (value: string, index: number, array: string[]) => unknown, thisArg?: any): boolean;
        forEach(callbackfn: (value: string, index: number, array: string[]) => void, thisArg?: any): void;
        map<U>(callbackfn: (value: string, index: number, array: string[]) => U, thisArg?: any): U[];
        filter<S_1 extends string>(predicate: (value: string, index: number, array: string[]) => value is S_1, thisArg?: any): S_1[];
        filter(predicate: (value: string, index: number, array: string[]) => unknown, thisArg?: any): string[];
        reduce(callbackfn: (previousValue: string, currentValue: string, currentIndex: number, array: string[]) => string): string;
        reduce(callbackfn: (previousValue: string, currentValue: string, currentIndex: number, array: string[]) => string, initialValue: string): string;
        reduce<U_1>(callbackfn: (previousValue: U_1, currentValue: string, currentIndex: number, array: string[]) => U_1, initialValue: U_1): U_1;
        reduceRight(callbackfn: (previousValue: string, currentValue: string, currentIndex: number, array: string[]) => string): string;
        reduceRight(callbackfn: (previousValue: string, currentValue: string, currentIndex: number, array: string[]) => string, initialValue: string): string;
        reduceRight<U_2>(callbackfn: (previousValue: U_2, currentValue: string, currentIndex: number, array: string[]) => U_2, initialValue: U_2): U_2;
        find<S_2 extends string>(predicate: (this: void, value: string, index: number, obj: string[]) => value is S_2, thisArg?: any): S_2;
        find(predicate: (value: string, index: number, obj: string[]) => unknown, thisArg?: any): string;
        findIndex(predicate: (value: string, index: number, obj: string[]) => unknown, thisArg?: any): number;
        fill(value: string, start?: number, end?: number): string[];
        copyWithin(target: number, start: number, end?: number): string[];
        entries(): IterableIterator<[number, string]>;
        keys(): IterableIterator<number>;
        values(): IterableIterator<string>;
        includes(searchElement: string, fromIndex?: number): boolean;
        flatMap<U_3, This = undefined>(callback: (this: This, value: string, index: number, array: string[]) => U_3 | readonly U_3[], thisArg?: This): U_3[];
        flat<A, D extends number = 1>(this: A, depth?: D): FlatArray<A, D>[];
        [Symbol.iterator](): IterableIterator<string>;
        [Symbol.unscopables](): {
            copyWithin: boolean;
            entries: boolean;
            fill: boolean;
            find: boolean;
            findIndex: boolean;
            keys: boolean;
            values: boolean;
        };
    };
    readonly mediaQueries: {
        tablet: string;
        desktop: string;
    };
    readonly sizes: {
        [x: number]: string;
        vW: string;
        vH: string;
        quarter: string;
        third: string;
        half: string;
        twoThird: string;
        threeQuarter: string;
        full: string;
        icons: string[];
        1: string;
    };
    readonly fonts: {
        body: string;
        heading: string;
        monospace: string;
    };
    readonly fontWeights: {
        regular: number;
        bold: number;
        body: number;
        heading: number;
        normal: number;
    };
    readonly colors: {
        line: string;
        buttonRed: string;
        buttonBlue: string;
        green50: string;
        green100: string;
        green200: string;
        green300: string;
        green400: string;
        green500: string;
        green600: string;
        green700: string;
        green800: string;
        green900: string;
        yellow50: string;
        yellow100: string;
        yellow200: string;
        yellow300: string;
        yellow400: string;
        yellow500: string;
        yellow600: string;
        yellow700: string;
        yellow800: string;
        yellow900: string;
        white: string;
        black: string;
        backgroundIOS: string;
        grayIOS: string;
        text: string;
        textLighter: string;
        link: string;
        primary: string;
        secondary: string;
        green: string;
        yellow: string;
        border: string;
        background: string;
        text038: string;
        text060: string;
        text087: string;
        text025: string;
        text600: string;
        text900: string;
        warning50: string;
        warning800: string;
        success50: string;
        success700: string;
        error50: string;
        error900: string;
        surface1: string;
        surface2: string;
        surface3: string;
        surface25: string;
        surface100: string;
        surface300: string;
        surface500: string;
        surface700: string;
        surface900: string;
        gray50: string;
        gray100: string;
        gray200: string;
        gray300: string;
        gray400: string;
        gray500: string;
        gray600: string;
        gray700: string;
        gray800: string;
        gray900: string;
        darkgray1: string;
        darkgray2: string;
        darkgray3: string;
        darkgray4: string;
        gray1: string;
        gray2: string;
        gray3: string;
        gray4: string;
        gray5: string;
        secondary50: string;
        secondary100: string;
        secondary200: string;
        secondary300: string;
        secondary400: string;
        secondary500: string;
        secondary600: string;
        secondary700: string;
        secondary800: string;
        secondary900: string;
        primary50: string;
        primary100: string;
        primary200: string;
        primary300: string;
        primary400: string;
        primary500: string;
        primary600: string;
        primary700: string;
        primary800: string;
        primary900: string;
    };
    readonly radii: {
        none: number;
        xs: string;
        sm: string;
        md: string;
        lg: string;
        xl: string;
        pill: string;
        circle: string;
    };
    readonly inputHeights: {
        sm: string;
        md: string;
        xs: string;
    };
    readonly texts: {
        text038: string;
        text060: string;
        text087: string;
        text025: string;
        text600: string;
        text900: string;
    };
    readonly zIndices: {
        initial: string;
        neutral: number;
        up: number;
        down: number;
        notification: number;
        tooltip: number;
        modal: number;
        dropdown: number;
    };
}['fontWeights'];
export type Radii = keyof {
    readonly breakpoints: {
        sm: string;
        md: string;
        lg: string;
        xl: string;
        xxl: string;
        length: number;
        toString(): string;
        toLocaleString(): string;
        pop(): string;
        push(...items: string[]): number;
        concat(...items: ConcatArray<string>[]): string[];
        concat(...items: (string | ConcatArray<string>)[]): string[];
        join(separator?: string): string;
        reverse(): string[];
        shift(): string;
        slice(start?: number, end?: number): string[];
        sort(compareFn?: (a: string, b: string) => number): string[];
        splice(start: number, deleteCount?: number): string[];
        splice(start: number, deleteCount: number, ...items: string[]): string[];
        unshift(...items: string[]): number;
        indexOf(searchElement: string, fromIndex?: number): number;
        lastIndexOf(searchElement: string, fromIndex?: number): number;
        every<S extends string>(predicate: (value: string, index: number, array: string[]) => value is S, thisArg?: any): this is S[];
        every(predicate: (value: string, index: number, array: string[]) => unknown, thisArg?: any): boolean;
        some(predicate: (value: string, index: number, array: string[]) => unknown, thisArg?: any): boolean;
        forEach(callbackfn: (value: string, index: number, array: string[]) => void, thisArg?: any): void;
        map<U>(callbackfn: (value: string, index: number, array: string[]) => U, thisArg?: any): U[];
        filter<S_1 extends string>(predicate: (value: string, index: number, array: string[]) => value is S_1, thisArg?: any): S_1[];
        filter(predicate: (value: string, index: number, array: string[]) => unknown, thisArg?: any): string[];
        reduce(callbackfn: (previousValue: string, currentValue: string, currentIndex: number, array: string[]) => string): string;
        reduce(callbackfn: (previousValue: string, currentValue: string, currentIndex: number, array: string[]) => string, initialValue: string): string;
        reduce<U_1>(callbackfn: (previousValue: U_1, currentValue: string, currentIndex: number, array: string[]) => U_1, initialValue: U_1): U_1;
        reduceRight(callbackfn: (previousValue: string, currentValue: string, currentIndex: number, array: string[]) => string): string;
        reduceRight(callbackfn: (previousValue: string, currentValue: string, currentIndex: number, array: string[]) => string, initialValue: string): string;
        reduceRight<U_2>(callbackfn: (previousValue: U_2, currentValue: string, currentIndex: number, array: string[]) => U_2, initialValue: U_2): U_2;
        find<S_2 extends string>(predicate: (this: void, value: string, index: number, obj: string[]) => value is S_2, thisArg?: any): S_2;
        find(predicate: (value: string, index: number, obj: string[]) => unknown, thisArg?: any): string;
        findIndex(predicate: (value: string, index: number, obj: string[]) => unknown, thisArg?: any): number;
        fill(value: string, start?: number, end?: number): string[];
        copyWithin(target: number, start: number, end?: number): string[];
        entries(): IterableIterator<[number, string]>;
        keys(): IterableIterator<number>;
        values(): IterableIterator<string>;
        includes(searchElement: string, fromIndex?: number): boolean;
        flatMap<U_3, This = undefined>(callback: (this: This, value: string, index: number, array: string[]) => U_3 | readonly U_3[], thisArg?: This): U_3[];
        flat<A, D extends number = 1>(this: A, depth?: D): FlatArray<A, D>[];
        [Symbol.iterator](): IterableIterator<string>;
        [Symbol.unscopables](): {
            copyWithin: boolean;
            entries: boolean;
            fill: boolean;
            find: boolean;
            findIndex: boolean;
            keys: boolean;
            values: boolean;
        };
    };
    readonly mediaQueries: {
        tablet: string;
        desktop: string;
    };
    readonly sizes: {
        [x: number]: string;
        vW: string;
        vH: string;
        quarter: string;
        third: string;
        half: string;
        twoThird: string;
        threeQuarter: string;
        full: string;
        icons: string[];
        1: string;
    };
    readonly fonts: {
        body: string;
        heading: string;
        monospace: string;
    };
    readonly fontWeights: {
        regular: number;
        bold: number;
        body: number;
        heading: number;
        normal: number;
    };
    readonly colors: {
        line: string;
        buttonRed: string;
        buttonBlue: string;
        green50: string;
        green100: string;
        green200: string;
        green300: string;
        green400: string;
        green500: string;
        green600: string;
        green700: string;
        green800: string;
        green900: string;
        yellow50: string;
        yellow100: string;
        yellow200: string;
        yellow300: string;
        yellow400: string;
        yellow500: string;
        yellow600: string;
        yellow700: string;
        yellow800: string;
        yellow900: string;
        white: string;
        black: string;
        backgroundIOS: string;
        grayIOS: string;
        text: string;
        textLighter: string;
        link: string;
        primary: string;
        secondary: string;
        green: string;
        yellow: string;
        border: string;
        background: string;
        text038: string;
        text060: string;
        text087: string;
        text025: string;
        text600: string;
        text900: string;
        warning50: string;
        warning800: string;
        success50: string;
        success700: string;
        error50: string;
        error900: string;
        surface1: string;
        surface2: string;
        surface3: string;
        surface25: string;
        surface100: string;
        surface300: string;
        surface500: string;
        surface700: string;
        surface900: string;
        gray50: string;
        gray100: string;
        gray200: string;
        gray300: string;
        gray400: string;
        gray500: string;
        gray600: string;
        gray700: string;
        gray800: string;
        gray900: string;
        darkgray1: string;
        darkgray2: string;
        darkgray3: string;
        darkgray4: string;
        gray1: string;
        gray2: string;
        gray3: string;
        gray4: string;
        gray5: string;
        secondary50: string;
        secondary100: string;
        secondary200: string;
        secondary300: string;
        secondary400: string;
        secondary500: string;
        secondary600: string;
        secondary700: string;
        secondary800: string;
        secondary900: string;
        primary50: string;
        primary100: string;
        primary200: string;
        primary300: string;
        primary400: string;
        primary500: string;
        primary600: string;
        primary700: string;
        primary800: string;
        primary900: string;
    };
    readonly radii: {
        none: number;
        xs: string;
        sm: string;
        md: string;
        lg: string;
        xl: string;
        pill: string;
        circle: string;
    };
    readonly inputHeights: {
        sm: string;
        md: string;
        xs: string;
    };
    readonly texts: {
        text038: string;
        text060: string;
        text087: string;
        text025: string;
        text600: string;
        text900: string;
    };
    readonly zIndices: {
        initial: string;
        neutral: number;
        up: number;
        down: number;
        notification: number;
        tooltip: number;
        modal: number;
        dropdown: number;
    };
}['radii'];
export type Sizes = keyof {
    readonly breakpoints: {
        sm: string;
        md: string;
        lg: string;
        xl: string;
        xxl: string;
        length: number;
        toString(): string;
        toLocaleString(): string;
        pop(): string;
        push(...items: string[]): number;
        concat(...items: ConcatArray<string>[]): string[];
        concat(...items: (string | ConcatArray<string>)[]): string[];
        join(separator?: string): string;
        reverse(): string[];
        shift(): string;
        slice(start?: number, end?: number): string[];
        sort(compareFn?: (a: string, b: string) => number): string[];
        splice(start: number, deleteCount?: number): string[];
        splice(start: number, deleteCount: number, ...items: string[]): string[];
        unshift(...items: string[]): number;
        indexOf(searchElement: string, fromIndex?: number): number;
        lastIndexOf(searchElement: string, fromIndex?: number): number;
        every<S extends string>(predicate: (value: string, index: number, array: string[]) => value is S, thisArg?: any): this is S[];
        every(predicate: (value: string, index: number, array: string[]) => unknown, thisArg?: any): boolean;
        some(predicate: (value: string, index: number, array: string[]) => unknown, thisArg?: any): boolean;
        forEach(callbackfn: (value: string, index: number, array: string[]) => void, thisArg?: any): void;
        map<U>(callbackfn: (value: string, index: number, array: string[]) => U, thisArg?: any): U[];
        filter<S_1 extends string>(predicate: (value: string, index: number, array: string[]) => value is S_1, thisArg?: any): S_1[];
        filter(predicate: (value: string, index: number, array: string[]) => unknown, thisArg?: any): string[];
        reduce(callbackfn: (previousValue: string, currentValue: string, currentIndex: number, array: string[]) => string): string;
        reduce(callbackfn: (previousValue: string, currentValue: string, currentIndex: number, array: string[]) => string, initialValue: string): string;
        reduce<U_1>(callbackfn: (previousValue: U_1, currentValue: string, currentIndex: number, array: string[]) => U_1, initialValue: U_1): U_1;
        reduceRight(callbackfn: (previousValue: string, currentValue: string, currentIndex: number, array: string[]) => string): string;
        reduceRight(callbackfn: (previousValue: string, currentValue: string, currentIndex: number, array: string[]) => string, initialValue: string): string;
        reduceRight<U_2>(callbackfn: (previousValue: U_2, currentValue: string, currentIndex: number, array: string[]) => U_2, initialValue: U_2): U_2;
        find<S_2 extends string>(predicate: (this: void, value: string, index: number, obj: string[]) => value is S_2, thisArg?: any): S_2;
        find(predicate: (value: string, index: number, obj: string[]) => unknown, thisArg?: any): string;
        findIndex(predicate: (value: string, index: number, obj: string[]) => unknown, thisArg?: any): number;
        fill(value: string, start?: number, end?: number): string[];
        copyWithin(target: number, start: number, end?: number): string[];
        entries(): IterableIterator<[number, string]>;
        keys(): IterableIterator<number>;
        values(): IterableIterator<string>;
        includes(searchElement: string, fromIndex?: number): boolean;
        flatMap<U_3, This = undefined>(callback: (this: This, value: string, index: number, array: string[]) => U_3 | readonly U_3[], thisArg?: This): U_3[];
        flat<A, D extends number = 1>(this: A, depth?: D): FlatArray<A, D>[];
        [Symbol.iterator](): IterableIterator<string>;
        [Symbol.unscopables](): {
            copyWithin: boolean;
            entries: boolean;
            fill: boolean;
            find: boolean;
            findIndex: boolean;
            keys: boolean;
            values: boolean;
        };
    };
    readonly mediaQueries: {
        tablet: string;
        desktop: string;
    };
    readonly sizes: {
        [x: number]: string;
        vW: string;
        vH: string;
        quarter: string;
        third: string;
        half: string;
        twoThird: string;
        threeQuarter: string;
        full: string;
        icons: string[];
        1: string;
    };
    readonly fonts: {
        body: string;
        heading: string;
        monospace: string;
    };
    readonly fontWeights: {
        regular: number;
        bold: number;
        body: number;
        heading: number;
        normal: number;
    };
    readonly colors: {
        line: string;
        buttonRed: string;
        buttonBlue: string;
        green50: string;
        green100: string;
        green200: string;
        green300: string;
        green400: string;
        green500: string;
        green600: string;
        green700: string;
        green800: string;
        green900: string;
        yellow50: string;
        yellow100: string;
        yellow200: string;
        yellow300: string;
        yellow400: string;
        yellow500: string;
        yellow600: string;
        yellow700: string;
        yellow800: string;
        yellow900: string;
        white: string;
        black: string;
        backgroundIOS: string;
        grayIOS: string;
        text: string;
        textLighter: string;
        link: string;
        primary: string;
        secondary: string;
        green: string;
        yellow: string;
        border: string;
        background: string;
        text038: string;
        text060: string;
        text087: string;
        text025: string;
        text600: string;
        text900: string;
        warning50: string;
        warning800: string;
        success50: string;
        success700: string;
        error50: string;
        error900: string;
        surface1: string;
        surface2: string;
        surface3: string;
        surface25: string;
        surface100: string;
        surface300: string;
        surface500: string;
        surface700: string;
        surface900: string;
        gray50: string;
        gray100: string;
        gray200: string;
        gray300: string;
        gray400: string;
        gray500: string;
        gray600: string;
        gray700: string;
        gray800: string;
        gray900: string;
        darkgray1: string;
        darkgray2: string;
        darkgray3: string;
        darkgray4: string;
        gray1: string;
        gray2: string;
        gray3: string;
        gray4: string;
        gray5: string;
        secondary50: string;
        secondary100: string;
        secondary200: string;
        secondary300: string;
        secondary400: string;
        secondary500: string;
        secondary600: string;
        secondary700: string;
        secondary800: string;
        secondary900: string;
        primary50: string;
        primary100: string;
        primary200: string;
        primary300: string;
        primary400: string;
        primary500: string;
        primary600: string;
        primary700: string;
        primary800: string;
        primary900: string;
    };
    readonly radii: {
        none: number;
        xs: string;
        sm: string;
        md: string;
        lg: string;
        xl: string;
        pill: string;
        circle: string;
    };
    readonly inputHeights: {
        sm: string;
        md: string;
        xs: string;
    };
    readonly texts: {
        text038: string;
        text060: string;
        text087: string;
        text025: string;
        text600: string;
        text900: string;
    };
    readonly zIndices: {
        initial: string;
        neutral: number;
        up: number;
        down: number;
        notification: number;
        tooltip: number;
        modal: number;
        dropdown: number;
    };
}['sizes'];
/**
 * - Themeable style object
 */
export type ThemableStyle = {
    fontFamily?: Fonts | Fonts[];
    fontWeight?: FontWeights | FontWeights[];
    lineHeight?: string | string[];
    letterSpacing?: string | string[];
    color?: Colors | Colors[];
    backgroundColor?: Colors | Colors[];
    /**
     * short hand for background color
     */
    bg?: Colors | Colors[];
    border?: string | string[];
    borderTop?: string | string[];
    borderRight?: string | string[];
    borderBottom?: string | string[];
    borderLeft?: string | string[];
    borderColor?: Colors | Colors[];
    borderStyle?: string | string[];
    borderRadius?: Radii | Radii[];
    zIndex?: number | number[];
    width?: Sizes | Sizes[];
    minWidth?: Sizes | Sizes[];
    maxWidth?: Sizes | Sizes[];
    height?: Sizes | Sizes[];
    minHeight?: Sizes | Sizes[];
    maxHeight?: Sizes | Sizes[];
    size?: Sizes | Sizes[];
};
/**
 * All standard CSS properties as regular object, except those from ThemableStyle
 */
export type StandardCSSProperties = Omit<CSSProperties, keyof ThemableStyle>;
