import css from '@styled-system/css';
import theme from '../theme';
/**
 * @typedef {import('styled-system__css').CSSProperties} CSSProperties
 * @typedef {import('styled-system__css').SystemStyleObject} SystemStyleObject
 */
/**
 * @typedef { keyof theme['colors'] } Colors
 * @typedef { keyof theme['fonts'] } Fonts
 * @typedef { keyof theme['fontWeights'] } FontWeights
 * @typedef { keyof theme['radii'] } Radii
 * @typedef { keyof theme['sizes'] } Sizes
 */

/**
 * @typedef {object} ThemableStyle - Themeable style object
 * @property {Fonts | Fonts[]}                 [fontFamily]
 * @property {FontWeights | FontWeights[]}     [fontWeight]
 * @property {string | string[]}               [lineHeight]
 * @property {string | string[]}               [letterSpacing]
 * @property {Colors | Colors[]}               [color]
 * @property {Colors | Colors[]}               [backgroundColor]
 * @property {Colors | Colors[]}               [bg] short hand for background color
 * @property {string | string[]}               [border]
 * @property {string | string[]}               [borderTop]
 * @property {string | string[]}               [borderRight]
 * @property {string | string[]}               [borderBottom]
 * @property {string | string[]}               [borderLeft]
 * @property {Colors | Colors[]}               [borderColor]
 * @property {string|string[]}                 [borderStyle]
 * @property {Radii | Radii[] }                [borderRadius]
 * @property {number | number[]}               [zIndex]
 * @property {Sizes | Sizes[]}                 [width]
 * @property {Sizes | Sizes[]}                 [minWidth]
 * @property {Sizes | Sizes[]}                 [maxWidth]
 * @property {Sizes | Sizes[]}                 [height]
 * @property {Sizes | Sizes[]}                 [minHeight]
 * @property {Sizes | Sizes[]}                 [maxHeight]
 * @property {Sizes | Sizes[]}                 [size]
 */

/**
 * @typedef {Omit<CSSProperties, keyof ThemableStyle>} StandardCSSProperties All standard CSS properties as regular object, except those from ThemableStyle
 */

/**
 * Helper get CSS from theme-aware style object and theme
 * @param {ThemableStyle | StandardCSSProperties} styles
 * @return {import('styled-system__css').CSSObject}
 */
export default function sx(styles = {}) {
  // @ts-ignore ThemableStyle is not compatible with SystemStyleObject
  return css(styles)(theme);
}
